@@ -5,13 +5,15 @@
 
 #define N 16
  
+__attribute__ ((noinline))
 int main1 ()
 {  
+  int i;
   struct {
     char ca[N];
     char cb[N];
   } s;
-  int i;
+
 
   for (i = 0; i < N; i++)
     {
@@ -41,6 +43,4 @@ int main (void)
 } 
 
 /* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect" } } */
-/* { dg-final { scan-tree-dump-times "Vectorizing an unaligned access" 0 "vect" } } */
-/* { dg-final { scan-tree-dump-times "Alignment of access forced using peeling" 0 "vect" } } */
 /* { dg-final { cleanup-tree-dump "vect" } } */
