@@ -6,5 +6,7 @@ program test
   50 FORMAT (d20.0)
   astr = ""
   write(astr,50) -8.0D0
+  if (astr.ne."             -0.D+01") call abort()
+  write(astr,50) 8.0D0
   if (astr.ne."              0.D+01") call abort()
 end program test
